@@ -276,7 +276,7 @@ class MessageProcessor(object):
             logger.debug("[{}] - Current slot values: \n{}".format(tracker.sender_id, slot_values))
 
     def _is_nlu_threshold_passed(self, nlu_data, tracker):
-        if self.policy_ensemble is None or tracker.active_form:
+        if self.policy_ensemble is None or tracker.active_form or tracker.get_slot("handoff_active"):
             return True
 
         form_fallback_policy = self.policy_ensemble.look_up_policy(FormFallbackPolicy)
@@ -313,6 +313,7 @@ class MessageProcessor(object):
             self, message: UserMessage, tracker: DialogueStateTracker
     ) -> Dict:
         requested_slot = tracker.get_slot("requested_slot")
+        handoff_active = tracker.get_slot("handoff_active")
 
         if message.metadata and message.metadata.get("replyType"):
             metadata = {"type": message.metadata.get("replyType")}
@@ -321,6 +322,9 @@ class MessageProcessor(object):
 
         if tracker.active_form.get("name"):
             metadata["active_form"] = tracker.active_form.get("name")
+        
+        if handoff_active:
+            metadata["handoff_active"] = handoff_active
 
         if requested_slot:
             metadata["requested_slot"] = requested_slot
@@ -448,6 +452,8 @@ class MessageProcessor(object):
             if not isinstance(e, BotUttered):
                 continue
 
+            if tracker.get_slot("handoff_active") and not tracker.get_slot("initializing_handoff"):
+                e.type_name = "liveAgent"
             await output_channel.send_response(tracker.sender_id, e.message())
 
     async def _schedule_reminders(
