@@ -7,6 +7,7 @@ from typing import List, Optional, Text, Union
 
 from sanic import Sanic
 from sanic_cors import CORS
+from sanic_prometheus import monitor
 
 import rasa.core
 import rasa.utils
@@ -183,11 +184,27 @@ def serve_application(
         if app.agent.model_directory:
             shutil.rmtree(app.agent.model_directory)
 
+    async def close_session(app: Sanic, _loop: Text) -> None:
+        """Clean up active user sessions before shutting down server"""
+        logger.info("Shutting down Sanic server now...")
+
+        for input_channel in app.input_channels:
+            if input_channel.is_socketio_channel():
+                await input_channel.disconnect_session()
+
+        if app.agent.tracker_store.event_broker:
+            app.agent.tracker_store.event_broker.flush()
+
+        if app.session:
+            await app.session.close()
+
     app.register_listener(clear_model_files, "after_server_stop")
+    app.register_listener(close_session, "before_server_stop")
 
     update_sanic_log_level(log_file)
     num_workers = int(os.environ.get("NUM_WORKERS", 1))
     logger.info("Spawning {} Sanic workers....".format(num_workers))
+    monitor(app).expose_endpoint()
     app.run(host="0.0.0.0", port=port, access_log=False, workers=num_workers)
 
 
