@@ -12,7 +12,7 @@ class KeywordIntentClassifier(Component):
 
     byes = ["bye", "goodbye"]
 
-    def process(self, message: Message, **kwargs: Any) -> None:
+    async def process(self, message: Message, **kwargs: Any) -> None:
 
         intent = {"name": self.parse(message.text), "confidence": 1.0}
         message.set("intent", intent, add_to_output=True)
