@@ -601,7 +601,7 @@ def align_all_entity_predictions(
     return aligned_predictions
 
 
-def get_eval_data(
+async def get_eval_data(
     interpreter: Interpreter, test_data: TrainingData
 ) -> Tuple[
     List[IntentEvaluationResult], List[EntityEvaluationResult]
@@ -623,7 +623,7 @@ def get_eval_data(
     should_eval_entities = is_entity_extractor_present(interpreter)
 
     for example in tqdm(test_data.training_examples):
-        result = interpreter.parse(example.text, only_output_properties=False)
+        result = await interpreter.parse(example.text, only_output_properties=False)
 
         if should_eval_intents:
             intent_prediction = result.get("intent", {}) or {}
@@ -680,7 +680,7 @@ def remove_pretrained_extractors(pipeline: List[Component]) -> List[Component]:
     return pipeline
 
 
-def run_evaluation(
+async def run_evaluation(
     data_path: Text,
     model_path: Text,
     report: Optional[Text] = None,
@@ -719,7 +719,7 @@ def run_evaluation(
     if report:
         io_utils.create_directory(report)
 
-    intent_results, entity_results = get_eval_data(interpreter, test_data)
+    intent_results, entity_results = await get_eval_data(interpreter, test_data)
 
     if intent_results:
         logger.info("Intent evaluation results:")
@@ -904,7 +904,7 @@ def compute_metrics(
     Returns intent and entity metrics, and prediction results.
     """
 
-    intent_results, entity_results = get_eval_data(interpreter, corpus)
+    intent_results, entity_results = asyncio.get_event_loop().run_until_complete(get_eval_data(interpreter, corpus))
 
     intent_results = remove_empty_intent_examples(intent_results)
 
@@ -1001,9 +1001,9 @@ def compare_nlu(
                     model_output_path, "{}_report".format(model_name)
                 )
                 errors_path = os.path.join(report_path, "errors.json")
-                result = run_evaluation(
+                result = asyncio.get_event_loop().run_until_complete(run_evaluation(
                     test_path, model_path, report=report_path, errors=errors_path
-                )
+                ))
 
                 f1 = result["intent_evaluation"]["f1_score"]
                 f_score_results[model_name][run].append(f1)
