@@ -1102,6 +1102,10 @@ def create_app(
             )
 
         tracker = obtain_tracker_store(app.agent, conversation_id)
+        if tracker.latest_action_name == "action_human_end_conversation":
+            await app.agent.execute_action(
+                conversation_id, "action_listen", output_channel, policy, confidence
+            )
         state = tracker.current_state(verbosity)
 
         response_body = {"tracker": state}
